pub struct Repo {
pub created_at: DateTime<Utc>,
pub description: Option<String>,
pub id: Uuid,
pub name: String,
pub owner_id: Uuid,
pub readme: Option<String>,
pub updated_at: DateTime<Utc>,
pub visibility: Visibility,
}Expand description
A repository — a named workspace of paths and graphs owned by a
single user. name is unique per owner and serves as the URL
segment in /{owner}/{name} and nested resources.
JSON schema
{
"description": "A repository — a named workspace of paths and graphs owned by a\nsingle user. `name` is unique per owner and serves as the URL\nsegment in `/{owner}/{name}` and nested resources.",
"type": "object",
"required": [
"created_at",
"id",
"name",
"owner_id",
"updated_at",
"visibility"
],
"properties": {
"created_at": {
"type": "string",
"format": "date-time"
},
"description": {
"type": [
"string",
"null"
]
},
"id": {
"type": "string",
"format": "uuid"
},
"name": {
"type": "string"
},
"owner_id": {
"type": "string",
"format": "uuid"
},
"readme": {
"type": [
"string",
"null"
]
},
"updated_at": {
"type": "string",
"format": "date-time"
},
"visibility": {
"$ref": "#/components/schemas/Visibility"
}
}
}Fields
created_at: DateTime<Utc>description: Option<String>id: Uuidname: Stringowner_id: Uuidreadme: Option<String>updated_at: DateTime<Utc>visibility: VisibilityTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Repo
impl<'de> Deserialize<'de> for Repo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more