pub struct ToolInvocation {
pub actor_id: i32,
pub input: Option<String>,
pub result: Option<String>,
pub step_id: String,
pub text: Option<String>,
pub text_html: String,
pub timestamp: Option<String>,
pub tool_diff: Option<ToolDiff>,
pub tool_name: Option<String>,
}Expand description
A tool.invoke step spliced inline next to its parent assistant
turn. Saves the client a second pass over the path’s step graph.
JSON schema
{
"description": "A `tool.invoke` step spliced inline next to its parent assistant\nturn. Saves the client a second pass over the path's step graph.",
"type": "object",
"required": [
"actor_id",
"step_id",
"text_html"
],
"properties": {
"actor_id": {
"type": "integer",
"format": "int32",
"minimum": 0.0
},
"input": {
"description": "Tool input args from the structural payload (`extra.input`),\nJSON-stringified when not already a string.",
"type": [
"string",
"null"
]
},
"result": {
"description": "Tool output from the structural payload (`extra.result`),\nJSON-stringified when not already a string.",
"type": [
"string",
"null"
]
},
"step_id": {
"description": "Canonical step ID of the tool.invoke step.",
"type": "string"
},
"text": {
"type": [
"string",
"null"
]
},
"text_html": {
"type": "string"
},
"timestamp": {
"type": [
"string",
"null"
]
},
"tool_diff": {
"oneOf": [
{
"type": "null"
},
{
"allOf": [
{
"$ref": "#/components/schemas/ToolDiff"
}
]
}
]
},
"tool_name": {
"type": [
"string",
"null"
]
}
}
}Fields
actor_id: i32input: Option<String>Tool input args from the structural payload (extra.input),
JSON-stringified when not already a string.
result: Option<String>Tool output from the structural payload (extra.result),
JSON-stringified when not already a string.
step_id: StringCanonical step ID of the tool.invoke step.
text: Option<String>text_html: Stringtimestamp: Option<String>tool_diff: Option<ToolDiff>tool_name: Option<String>Trait Implementations
Sourceimpl Clone for ToolInvocation
impl Clone for ToolInvocation
Sourcefn clone(&self) -> ToolInvocation
fn clone(&self) -> ToolInvocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolInvocation
impl Debug for ToolInvocation
Sourceimpl<'de> Deserialize<'de> for ToolInvocation
impl<'de> Deserialize<'de> for ToolInvocation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more